==> 1.0.0.tar.gz: android/src/main/kotlin/com/plugin/aws_mqtt/AwsMqttPlugin.kt <==
package com.plugin.aws_mqtt

import android.os.Handler
import android.os.Looper
import android.util.Log
import androidx.annotation.NonNull
import com.amazonaws.services.iot.client.AWSIotMessage
import com.amazonaws.services.iot.client.AWSIotQos
import com.google.gson.Gson
import com.plugin.aws_mqtt.utilities.*
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.EventChannel.EventSink
import io.flutter.plugin.common.EventChannel.StreamHandler
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** AwsMqttPlugin */
class AwsMqttPlugin: FlutterPlugin, MethodCallHandler, StreamHandler, MqttCallback {

  private lateinit var channel: MethodChannel
  private lateinit var eventChannel: EventChannel
  private lateinit var mqttClient: MqttClient
  private lateinit var result: Result
  private lateinit var handler: Handler
  private lateinit var events: EventSink
  private lateinit var gson: Gson

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "methods")
    channel.setMethodCallHandler(this)
    eventChannel = EventChannel(flutterPluginBinding.binaryMessenger, "events");
    eventChannel.setStreamHandler(this)
    gson = Gson()
    handler = Handler(Looper.getMainLooper())
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
        "connect" -> {
          val clientEndpoint = call.argument<String>("clientEndpoint")!!
          val certificate = call.argument<String>("certificate")!!
          val privateKey = call.argument<String>("privateKey")!!
          val pair = AWSIotMqttUtil.getKeyStorePasswordPair(certificate, privateKey)
          mqttClient = MqttClient(clientEndpoint, pair, this)
          mqttClient.connectMqtt()
          result.success("connect - call success")
        }
        "disconnect" -> {
          if(this::mqttClient.isInitialized) {
            mqttClient.disconnectMqtt()
            result.success("disconnect - call success")
          } else {
            result.success("disconnect - client not initialized")
          }
        }
        "subscribe" -> {
          if(this::mqttClient.isInitialized) {
            val topicName = call.argument<String>("topicName")!!
            val qos = AWSIotQos.QOS0
            val topic = MqttTopic(topicName, qos, this)
            mqttClient.unsubscribe(topic)
            mqttClient.subscribe(topic)
            result.success("subscribe - call success")
          } else {
            result.success("subscribe - client not initialized")
          }
        }
        "publish" -> {
          if(this::mqttClient.isInitialized) {
            this.result = result
            val topicName = call.argument<String>("topicName")!!
            val payload = call.argument<String>("payload")!!
            val qos = AWSIotQos.QOS0
            val message = MqttMessage(topicName, qos, payload, this)
            mqttClient.publish(message, 3000)
          } else {
            result.success("publish - client not initialized")
          }
        }
        else -> {
          result.notImplemented()
        }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
    eventChannel.setStreamHandler(null)
  }

  override fun onConnectionSuccess() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionSuccess"
      events.success(gson.toJson(event))
    }
  }

  override fun onConnectionFailure() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionFailure"
      events.success(gson.toJson(event))
    }
  }

  override fun onConnectionClosed() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionClosed"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeSuccess() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeSuccess"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeFailure() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeFailure"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeTimeout() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeTimeout"
      events.success(gson.toJson(event))
    }
  }

  override fun onPublishSuccess() {
    handler.post {
      result.success("publish - call success")
    }
  }

  override fun onPublishFailure() {
    handler.post {
      result.success("publish - call fail")
    }
  }

  override fun onPublishTimeout() {
    handler.post {
      result.success("publish - call timeout")
    }
  }

  override fun onMessage(message: AWSIotMessage?) {
    handler.post {
      val event = EventObject()
      event.name = "onMessage"
      event.content = message!!.stringPayload
      events.success(gson.toJson(event))
    }
  }

  override fun onListen(arguments: Any?, events: EventSink?) {
    Log.d("EventChannel", "listening")
    this.events = events!!
  }

  override fun onCancel(arguments: Any?) {
    Log.d("EventChannel", "cancelled")
    this.events.endOfStream()
  }
}

==> 1.0.2.tar.gz: android/src/main/kotlin/com/plugin/aws_mqtt/AwsMqttPlugin.kt <==
package com.plugin.aws_mqtt

import android.os.Handler
import android.os.Looper
import android.util.Log
import androidx.annotation.NonNull
import com.amazonaws.services.iot.client.AWSIotMessage
import com.amazonaws.services.iot.client.AWSIotQos
import com.google.gson.Gson
import com.plugin.aws_mqtt.utilities.*
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.EventChannel.EventSink
import io.flutter.plugin.common.EventChannel.StreamHandler
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** AwsMqttPlugin */
class AwsMqttPlugin: FlutterPlugin, MethodCallHandler, StreamHandler, MqttCallback {

  private lateinit var channel: MethodChannel
  private lateinit var eventChannel: EventChannel
  private lateinit var mqttClient: MqttClient
  private lateinit var result: Result
  private lateinit var handler: Handler
  private lateinit var events: EventSink
  private lateinit var gson: Gson

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "awsmqtt_methods")
    channel.setMethodCallHandler(this)
    eventChannel = EventChannel(flutterPluginBinding.binaryMessenger, "awsmqtt_events");
    eventChannel.setStreamHandler(this)
    gson = Gson()
    handler = Handler(Looper.getMainLooper())
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
        "connect" -> {
          val clientEndpoint = call.argument<String>("clientEndpoint")!!
          val certificate = call.argument<String>("certificate")!!
          val privateKey = call.argument<String>("privateKey")!!
          val pair = AWSIotMqttUtil.getKeyStorePasswordPair(certificate, privateKey)
          mqttClient = MqttClient(clientEndpoint, pair, this)
          mqttClient.connectMqtt()
          result.success("connect - call success")
        }
        "disconnect" -> {
          if(this::mqttClient.isInitialized) {
            mqttClient.disconnectMqtt()
            result.success("disconnect - call success")
          } else {
            result.success("disconnect - client not initialized")
          }
        }
        "subscribe" -> {
          if(this::mqttClient.isInitialized) {
            val topicName = call.argument<String>("topicName")!!
            val qos = AWSIotQos.QOS0
            val topic = MqttTopic(topicName, qos, this)
            mqttClient.unsubscribe(topic)
            mqttClient.subscribe(topic)
            result.success("subscribe - call success")
          } else {
            result.success("subscribe - client not initialized")
          }
        }
        "publish" -> {
          if(this::mqttClient.isInitialized) {
            this.result = result
            val topicName = call.argument<String>("topicName")!!
            val payload = call.argument<String>("payload")!!
            val qos = AWSIotQos.QOS0
            val message = MqttMessage(topicName, qos, payload, this)
            mqttClient.publish(message, 3000)
          } else {
            result.success("publish - client not initialized")
          }
        }
        else -> {
          result.notImplemented()
        }
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
    eventChannel.setStreamHandler(null)
  }

  override fun onConnectionSuccess() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionSuccess"
      events.success(gson.toJson(event))
    }
  }

  override fun onConnectionFailure() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionFailure"
      events.success(gson.toJson(event))
    }
  }

  override fun onConnectionClosed() {
    handler.post {
      val event = EventObject()
      event.name = "onConnectionClosed"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeSuccess() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeSuccess"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeFailure() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeFailure"
      events.success(gson.toJson(event))
    }
  }

  override fun onSubscribeTimeout() {
    handler.post {
      val event = EventObject()
      event.name = "onSubscribeTimeout"
      events.success(gson.toJson(event))
    }
  }

  override fun onPublishSuccess() {
    handler.post {
      result.success("publish - call success")
    }
  }

  override fun onPublishFailure() {
    handler.post {
      result.success("publish - call fail")
    }
  }

  override fun onPublishTimeout() {
    handler.post {
      result.success("publish - call timeout")
    }
  }

  override fun onMessage(message: AWSIotMessage?) {
    handler.post {
      val event = EventObject()
      event.name = "onMessage"
      event.content = message!!.stringPayload
      events.success(gson.toJson(event))
    }
  }

  override fun onListen(arguments: Any?, events: EventSink?) {
    Log.d("EventChannel", "listening")
    this.events = events!!
  }

  override fun onCancel(arguments: Any?) {
    Log.d("EventChannel", "cancelled")
    this.events.endOfStream()
  }
}
